sysdump(1M)

sysdump - generate a vmcore dump of a running IRIX system

As shipped in IRIX 6.5.22. Last changed in IRIX 6.5.22.

NAME
     sysdump - generate a vmcore dump of a running IRIX system

SYNOPSIS
     /usr/etc/sysdump [-d dumpdir] [-h] [-o dumpfile] [-s namelist]
     [-t dumplevel] [-v]

DESCRIPTION
     sysdump will create a vmcore crash dump of the currently running
     operating system without the need to halt the system.  The crash dump
     files can then be processed using icrash to determine the reasons for
     suspicious system behavior.

     Since the system is not halted during dump processing, kernel data may
     change in the middle of the dump operation.  This effect will be more
     pronounced at higher dump levels.

     The following options apply to sysdump:

     -d   Selects the directory where the crash dump files should be written.
          If specified, sysdump will check the directory for a bounds file,
          extract the numeric value, and create a file named
          vmcore.bounds.comp containing the memory image of the running
          system.  The system namelist file will be copied to the file
          unix.bounds.  The -d option behavior is default if neither -d nor -o
          is specified and the default value is /var/adm/crash.

     -h   Print a help summary of command operations.

     -o   Selects the specific output file to contain the generated crash dump
          file.  Only the vmcore memory image file is created.  The -o and -d
          options cannot be used simultaneously and there is no default value
          for -o.

     -s   Specifies the system namelist file that matches the running
          operating system.  By default, this value is /unix.  If the system
          has been booted from a file other than /unix, the -s option must be
          used to identify the correct file.

     -t   Specifies the dump level that controls the amount of information
          dumped.  Only level 0 and level 1 dumps are currently supported. A
          level 0 dump contains the putbuf, errbuf, and low memory.  A level 1
          dump adds static kernel, pfdat, backtrace, and dynamic kernel pages.

     -v   Provide verbose output. Operation is silent otherwise.

DIAGNOSTICS
SEE ALSO
     savecore(1M), uncompvm(1M), trcore(1m), icrash(1M).